angular.module('focaCrearHojaRuta')
    .service('focaCrearHojaRutaService', ['$http', 'API_ENDPOINT',
    function($http, API_ENDPOINT) {
        var route = API_ENDPOINT.URL;
        return {
            crearHojaRuta: function(hojaRuta) {
                return $http.post(route + '/hoja-ruta', hojaRuta);
            },
            obtenerHojaRuta: function() {
                return $http.get(route +'/hoja-ruta');
            },
            setHojaRuta: function(hojaRuta) {
                this.hojaRuta = hojaRuta;
            },
            clearHojaRuta: function() {
                this.hojaRuta = undefined;
            },
            getHojaRuta: function() {
                return this.hojaRuta;
            },
            getArticulosByIdHojaRuta: function(id) {
                return $http.get(route+'/articulos/hoja-ruta/'+id);
            },
            crearArticulosParaHojaRuta: function(articuloHojaRuta) {
                return $http.post(route + '/articulos/hoja-ruta',
                    {articuloHojaRuta: articuloHojaRuta});
            },
            getDomiciliosByIdHojaRuta: function(id) {
                return $http.get(route +'/hoja-ruta/' + id + '/domicilios');
            },
            getDomiciliosByIdCliente: function(id) {
                var idTipoEntrega = 2;//Solo traigo los domicilios que tienen tipo 2 (tipo entrega)
                return $http.get(route + '/domicilio/tipo/' + idTipoEntrega + '/cliente/' + id );
            },
            getPrecioCondicion: function() {
                return $http.get(route + '/precio-condicion');
            },
            getPrecioCondicionById: function(id) {
                return $http.get(route + '/precio-condicion/' + id);
            },
            getPlazoPagoByPrecioCondicion: function(id) {
                return $http.get(route + '/plazo-pago/precio-condicion/' + id);
            },
            crearFlete: function(flete) {
                return $http.post(route + '/flete', {flete : flete});
            },
            crearPlazosParaHojaRuta: function(plazos) {
                return $http.post(route + '/plazo-pago/hoja-ruta', plazos);
            },
            getCotizacionByIdMoneda: function(id) {
                return $http.get(route + '/moneda/' + id);
            },
            crearEstadoParaHojaRuta: function(estado) {
                return $http.post(route + '/estado', {estado: estado});
            },
            getNumeroHojaRuta: function() {
                return $http.get(route + '/hoja-ruta/numero-siguiente');
            },
            getRemitosByIdVehiculo: function(idVehiculo, fechaReparto, sinConfirmar) {
                var noCofirmados = sinConfirmar ? '/sinConfirmar' : '';
                return $http.get(route + '/vehiculo/obtener/remitos/' +
                    idVehiculo + '/' + fechaReparto.toISOString().substring(0, 10) + noCofirmados);
            },
            desasociarRemitos: function(idsRemitos, idVehiculo, sinRemitos) {
                return $http.post(route + '/vehiculo/desasociar-remitos',
                    {
                        idsRemitos: idsRemitos,
                        idVehiculo: idVehiculo,
                        vehiculoSinRemitos: sinRemitos
                    });
            },
            getBotonera: function() {
                return [
                    {
                        label: 'Fecha Entrega',
                        image: 'fechaDeReparto.png'
                    },
                    {
                        label: 'Transportista',
                        image: 'transportista.png'
                    },
                    {
                        label: 'Chofer',
                        image: 'chofer.png'
                    },
                    {
                        label: 'Vehiculo',
                        image: 'vehiculos.png'
                    },
                    {
                        label: 'Tarifario',
                        image: 'tarifario.png'
                    },
                    {
                        label: 'Remitos',
                        image: 'remito.png'
                    },
                    {
                        label: 'Vehiculos precargados',
                        image: 'vehiculos.png'
                    },
                    {
                        label: 'Datos extra',
                        image: 'tarifario.png'
                    }
                ];
            }
        };
    }]);
